@@ -34,6 +34,9 @@ class SharedBackendConf(SharedBackendConfUtils):
     def isH2OReplEnabled(self):
         return self._jconf.isH2OReplEnabled()
 
+    def isProgressBarEnabled(self):
+        return self._jconf.isProgressBarEnabled()
+
     def scalaIntDefaultNum(self):
         return self._jconf.scalaIntDefaultNum()
 
@@ -225,6 +228,14 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setReplDisabled()
         return self
 
+    def setProgressBarEnabled(self):
+        self._jconf.setProgressBarEnabled()
+        return self
+
+    def setProgressBarDisabled(self):
+        self._jconf.setProgressBarDisabled()
+        return self
+
     def setDefaultNumReplSessions(self, value):
         self._jconf.setDefaultNumReplSessions(value)
         return self
