@@ -378,7 +378,7 @@ class H2OAutoEncoderParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
     stoppingMetric = Param(
         Params._dummy(),
         "stoppingMetric",
-        """Metric to use for early stopping (AUTO: logloss for classification, deviance for regression and anomaly_score for Isolation Forest). Note that custom and custom_increasing can only be used in GBM and DRF with the Python client.""",
+        """Metric to use for early stopping (AUTO: logloss for classification, deviance for regression and anonomaly_score for Isolation Forest). Note that custom and custom_increasing can only be used in GBM and DRF with the Python client.""",
         H2OTypeConverters.toEnumString("hex.ScoreKeeper$StoppingMetric"))
 
     stoppingTolerance = Param(
