@@ -22,10 +22,9 @@ from ai.h2o.sparkling.ml.params.HasIgnoredCols import HasIgnoredCols
 from ai.h2o.sparkling.ml.params.HasPlugValues import HasPlugValues
 from ai.h2o.sparkling.ml.params.HasBetaConstraints import HasBetaConstraints
 from ai.h2o.sparkling.ml.params.HasInteractionPairs import HasInteractionPairs
-from ai.h2o.sparkling.ml.params.DeprecatedDistribution import DeprecatedDistribution
 
 
-class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstraints, HasInteractionPairs, DeprecatedDistribution, Params):
+class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstraints, HasInteractionPairs, Params):
 
     ##
     # Param definitions
@@ -258,6 +257,12 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
         """In case of linearly dependent columns, remove some of the dependent columns""",
         H2OTypeConverters.toBoolean())
 
+    generateScoringHistory = Param(
+        Params._dummy(),
+        "generateScoringHistory",
+        """If set to true, will generate scoring history for GLM.  This may significantly slow down the algo.""",
+        H2OTypeConverters.toBoolean())
+
     modelId = Param(
         Params._dummy(),
         "modelId",
@@ -297,7 +302,7 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     weightCol = Param(
         Params._dummy(),
         "weightCol",
-        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor.""",
+        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor. If you set weight = 0 for a row, the returned prediction frame at that row is zero and this is incorrect. To get an accurate prediction, remove all rows with weight == 0.""",
         H2OTypeConverters.toNullableString())
 
     offsetCol = Param(
@@ -330,6 +335,12 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
         """Whether to score during each iteration of model training.""",
         H2OTypeConverters.toBoolean())
 
+    checkpoint = Param(
+        Params._dummy(),
+        "checkpoint",
+        """Model checkpoint to resume training with.""",
+        H2OTypeConverters.toNullableString())
+
     stoppingRounds = Param(
         Params._dummy(),
         "stoppingRounds",
@@ -489,6 +500,9 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def getRemoveCollinearCols(self):
         return self.getOrDefault(self.removeCollinearCols)
 
+    def getGenerateScoringHistory(self):
+        return self.getOrDefault(self.generateScoringHistory)
+
     def getModelId(self):
         return self.getOrDefault(self.modelId)
 
@@ -525,6 +539,9 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def getScoreEachIteration(self):
         return self.getOrDefault(self.scoreEachIteration)
 
+    def getCheckpoint(self):
+        return self.getOrDefault(self.checkpoint)
+
     def getStoppingRounds(self):
         return self.getOrDefault(self.stoppingRounds)
 
@@ -663,6 +680,9 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def setRemoveCollinearCols(self, value):
         return self._set(removeCollinearCols=value)
 
+    def setGenerateScoringHistory(self, value):
+        return self._set(generateScoringHistory=value)
+
     def setModelId(self, value):
         return self._set(modelId=value)
 
@@ -699,6 +719,9 @@ class H2OGLMParams(HasRandomCols, HasIgnoredCols, HasPlugValues, HasBetaConstrai
     def setScoreEachIteration(self, value):
         return self._set(scoreEachIteration=value)
 
+    def setCheckpoint(self, value):
+        return self._set(checkpoint=value)
+
     def setStoppingRounds(self, value):
         return self._set(stoppingRounds=value)
 
