@@ -231,11 +231,11 @@ class H2OConnection(h2o_meta()):
     """
     Connection handle to an H2O cluster.
 
-    Typically, you don't need to access this class directly. Instead, use :func:`h2o.connect` to
-    establish a connection, and :func:`h2o.api` to make requests to the backend H2O server. However, if your
+    In a typical scenario you don't need to access this class directly. Instead use :func:`h2o.connect` to
+    establish a connection, and :func:`h2o.api` to make requests to the backend H2O server. However if your
     use-case is not typical, then read on.
 
-    Instances of this class may only be created through the static method :meth:`open`::
+    Instances of this class may only be created through a static method :meth:`open`::
 
         hc = H2OConnection.open(...)
 
@@ -243,7 +243,7 @@ class H2OConnection(h2o_meta()):
     If the script exits with an exception, then the connection will fail to close, and the backend server will
     keep all the temporary frames and the open session.
 
-    Alternatively, you can use this class as a context manager, which will ensure that the connection gets closed
+    Alternatively you can use this class as a context manager, which will ensure that the connection gets closed
     at the end of the ``with ...`` block even if an exception occurs::
 
         with H2OConnection.open() as hc:
@@ -264,9 +264,9 @@ class H2OConnection(h2o_meta()):
         r"""
         Establish connection to an existing H2O server.
 
-        The connection is not kept alive, so what this method actually does is attempt to connect to the
-        specified server, and check that the server is healthy and responds to REST API requests. If the H2O server
-        cannot be reached, an :class:`H2OConnectionError` will be raised. On a success, this method returns a new
+        The connection is not kept alive, so what this method actually does is it attempts to connect to the
+        specified server, and checks that the server is healthy and responds to REST API requests. If the H2O server
+        cannot be reached, an :class:`H2OConnectionError` will be raised. On success this method returns a new
         :class:`H2OConnection` object, and it is the only "official" way to create instances of this class.
 
         There are 3 ways to specify the target to connect to (these settings are mutually exclusive):
@@ -296,7 +296,7 @@ class H2OConnection(h2o_meta()):
             will attempt to use a proxy specified in the environment (in HTTP_PROXY / HTTPS_PROXY variables). We
             check for the presence of these variables and issue a warning if they are found. In order to suppress
             that warning and use proxy from the environment, pass ``proxy="(default)"``.
-        :param cookies: Cookie (or list of) to add to requests.
+        :param cookies: Cookie (or list of) to add to requests
         :param verbose: if True, then connection progress info will be printed to the stdout.
         :param strict_version_check: If True, an error will be raised if the client and server versions don't match.
         :param msgs: custom messages to display during connection. This is a tuple (initial message, success message,
@@ -422,9 +422,9 @@ class H2OConnection(h2o_meta()):
 
         :returns: an H2OResponse object representing the server's response (unless ``save_to`` parameter is
             provided, in which case the output file's name will be returned).
-        :raises H2OConnectionError: if the H2O server cannot be reached (or connection is not initialized).
-        :raises H2OServerError: if there was a server error (http 500), or server returned malformed JSON.
-        :raises H2OResponseError: if the server returned an H2OErrorV3 response (e.g. if the parameters were invalid).
+        :raises H2OConnectionError: if the H2O server cannot be reached (or connection is not initialized)
+        :raises H2OServerError: if there was a server error (http 500), or server returned malformed JSON
+        :raises H2OResponseError: if the server returned an H2OErrorV3 response (e.g. if the parameters were invalid)
         """
         if self._stage == 0: raise H2OConnectionError("Connection not initialized; run .connect() first.")
         if self._stage == -1: raise H2OConnectionError("Connection was closed, and can no longer be used.")
@@ -516,8 +516,8 @@ class H2OConnection(h2o_meta()):
         """
         Close an existing connection; once closed it cannot be used again.
 
-        Strictly speaking, it is not necessary to close all connections that you opened -- we have several mechanisms
-        in place that will do so automatically (``__del__()``, ``__exit__()``, and ``atexit()`` handlers), however there is also
+        Strictly speaking it is not necessary to close all connection that you opened -- we have several mechanisms
+        in place that will do so automatically (__del__(), __exit__() and atexit() handlers), however there is also
         no good reason to make this method private.
         """
         if self._session_id:
